@@ -1,11 +1,10 @@
 __author__ = "hugo.inzirillo"
 
-from npxlogger.logger_manager import NapoleonLoggerManager
+from npxlogger.logger_manager import log
 
 __all__ = ['log']
 __version__ = "0.0.1"
 
-log = NapoleonLoggerManager().get_logger(__package__)
 ########################## EXEMPLE ######################
 
 
